@@ -5,6 +5,18 @@
 //! ## Description
 //! **umya-spreadsheet** is a library written in pure Rust and read and write xlsx file.
 //!
+//! ## Support Status
+//! | Function | Remarks |
+//! | --- | --- |
+//! | file | read, write |
+//! | cell value | read, edit, formated value. |
+//! | cell style | read, edit |
+//! | columns | read, edit, auto width |
+//! | charts | detail to # Supported chart types |
+//! | drawings | read, edit(Still might be inconvenient.) |
+//! | images | read, edit(Still might be inconvenient.) |
+//! | ole objects | read, edit(Still might be inconvenient.) |
+//!
 //! ## Example
 // ![Result Image](images/sample1.png)
 //! ### Reader or New File
@@ -195,6 +207,7 @@ pub use self::structs::*;
 pub fn new_file() -> structs::Spreadsheet {
     let mut spreadsheet = structs::Spreadsheet::default();
     spreadsheet.set_theme(Theme::get_defalut_value());
+    spreadsheet.get_cell_styles_mut().set_defalut_value();
     let worksheet = spreadsheet.new_sheet("Sheet1").unwrap();
     worksheet.set_active_cell("A1");
     spreadsheet
