@@ -14,6 +14,7 @@ mod drawing;
 pub(crate) mod drawing_rels;
 pub(crate) mod embeddings;
 pub(crate) mod media;
+pub(crate) mod printer_settings;
 mod rels;
 mod shared_strings;
 mod styles;
@@ -139,6 +140,7 @@ pub fn read_reader<R: io::Read + io::Seek>(reader: R) -> Result<Spreadsheet, Xls
 
     book.remove_shared_string_table();
     book.remove_stylesheet();
+    book.get_cell_styles_mut().set_defalut_value();
 
     Ok(book)
 }
