@@ -1,12 +1,16 @@
+use super::driver::normalize_path_to_str;
+use super::XlsxError;
+use quick_xml::events::Event;
+use quick_xml::Reader;
 use std::io::Read;
 use std::{io, result};
-use quick_xml::Reader;
-use quick_xml::events::{Event};
-use super::XlsxError;
 use structs::drawing::charts::ChartSpace;
-use super::driver::normalize_path_to_str;
 
-pub(crate) fn read<R: io::Read + io::Seek>(arv: &mut zip::read::ZipArchive<R>, target: &String, chart_space: &mut ChartSpace) -> result::Result<(), XlsxError> {
+pub(crate) fn read<R: io::Read + io::Seek>(
+    arv: &mut zip::read::ZipArchive<R>,
+    target: &String,
+    chart_space: &mut ChartSpace,
+) -> result::Result<(), XlsxError> {
     let data = {
         let path_str = normalize_path_to_str(&format!("xl/drawings/{}", target));
         let mut r = io::BufReader::new(arv.by_name(path_str.as_str())?);
@@ -21,13 +25,11 @@ pub(crate) fn read<R: io::Read + io::Seek>(arv: &mut zip::read::ZipArchive<R>, t
 
     loop {
         match reader.read_event(&mut buf) {
-            Ok(Event::Start(ref e)) => {
-                match e.name() {
-                    b"c:chartSpace" => {
-                        chart_space.set_attributes(&mut reader, e);
-                    },
-                    _ => (),
+            Ok(Event::Start(ref e)) => match e.name() {
+                b"c:chartSpace" => {
+                    chart_space.set_attributes(&mut reader, e);
                 }
+                _ => (),
             },
             Ok(Event::Eof) => break,
             Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
