@@ -78,7 +78,7 @@ impl CellStyleFormats {
 
             // xf
             for cell_format in &self.cell_format {
-                cell_format.write_to(writer);
+                cell_format.write_to(writer, false);
             }
 
             write_end_tag(writer, "cellStyleXfs");
