@@ -1,52 +1,48 @@
 // c:numCache
 use super::FormatCode;
+use quick_xml::events::{BytesStart, Event};
+use quick_xml::Reader;
+use quick_xml::Writer;
+use std::io::Cursor;
 use structs::Address;
 use structs::Spreadsheet;
 use writer::driver::*;
-use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
-use quick_xml::Writer;
-use std::io::Cursor;
 
 #[derive(Clone, Default, Debug)]
 pub struct NumberingCache {
     format_code: FormatCode,
 }
 impl NumberingCache {
-    pub fn get_format_code(&self)-> &FormatCode {
+    pub fn get_format_code(&self) -> &FormatCode {
         &self.format_code
     }
 
-    pub fn get_format_code_mut(&mut self)-> &mut FormatCode {
+    pub fn get_format_code_mut(&mut self) -> &mut FormatCode {
         &mut self.format_code
     }
 
-    pub fn set_format_code(&mut self, value:FormatCode)-> &mut NumberingCache {
+    pub fn set_format_code(&mut self, value: FormatCode) -> &mut NumberingCache {
         self.format_code = value;
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        _e:&BytesStart
+        reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"c:formatCode" => {
-                            self.format_code.set_attributes(reader, e);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"c:formatCode" => {
+                        self.format_code.set_attributes(reader, e);
                     }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"c:numCache" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"c:numCache" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "c:numCache"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -56,7 +52,12 @@ impl NumberingCache {
         }
     }
 
-    pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>, address:&Address, spreadsheet: &Spreadsheet) {
+    pub(crate) fn write_to(
+        &self,
+        writer: &mut Writer<Cursor<Vec<u8>>>,
+        address: &Address,
+        spreadsheet: &Spreadsheet,
+    ) {
         let cell_value_list = spreadsheet.get_cell_value_by_address_crate(address);
         let coll_value_count = cell_value_list.len().to_string();
         // c:numCache
@@ -66,16 +67,22 @@ impl NumberingCache {
         &self.format_code.write_to(writer);
 
         // c:ptCount
-        write_start_tag(writer, "c:ptCount", vec![
-            ("val", coll_value_count.as_str()),
-        ], true);
+        write_start_tag(
+            writer,
+            "c:ptCount",
+            vec![("val", coll_value_count.as_str())],
+            true,
+        );
 
         let mut idx = 0;
         for cell_value in cell_value_list {
             // c:pt
-            write_start_tag(writer, "c:pt", vec![
-                ("idx", idx.to_string().as_str()),
-            ], false);
+            write_start_tag(
+                writer,
+                "c:pt",
+                vec![("idx", idx.to_string().as_str())],
+                false,
+            );
 
             // c:v
             write_start_tag(writer, "c:v", vec![], false);
