@@ -1,17 +1,17 @@
 // a:ln
-use super::TailEnd;
-use super::SolidFill;
-use super::GradientFill;
-use super::NoFill;
 use super::Bevel;
-use super::PresetDash;
+use super::GradientFill;
 use super::Miter;
-use writer::driver::*;
-use reader::driver::*;
+use super::NoFill;
+use super::PresetDash;
+use super::SolidFill;
+use super::TailEnd;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Outline {
@@ -31,7 +31,7 @@ impl Outline {
         &self.width
     }
 
-    pub fn set_width(&mut self, value:u32) {
+    pub fn set_width(&mut self, value: u32) {
         self.width = value;
     }
 
@@ -39,7 +39,7 @@ impl Outline {
         &self.cap_type
     }
 
-    pub fn set_cap_type<S: Into<String>>(&mut self, value:S) {
+    pub fn set_cap_type<S: Into<String>>(&mut self, value: S) {
         self.cap_type = Some(value.into());
     }
 
@@ -47,7 +47,7 @@ impl Outline {
         &self.compound_line_type
     }
 
-    pub fn set_compound_line_type<S: Into<String>>(&mut self, value:S) {
+    pub fn set_compound_line_type<S: Into<String>>(&mut self, value: S) {
         self.compound_line_type = Some(value.into());
     }
 
@@ -59,7 +59,7 @@ impl Outline {
         &mut self.solid_fill
     }
 
-    pub fn set_solid_fill(&mut self, value:SolidFill) {
+    pub fn set_solid_fill(&mut self, value: SolidFill) {
         self.solid_fill = Some(value);
     }
 
@@ -71,7 +71,7 @@ impl Outline {
         &mut self.gradient_fill
     }
 
-    pub fn set_gradient_fill(&mut self, value:GradientFill) {
+    pub fn set_gradient_fill(&mut self, value: GradientFill) {
         self.gradient_fill = Some(value);
     }
 
@@ -83,7 +83,7 @@ impl Outline {
         &mut self.tail_end
     }
 
-    pub fn set_tail_end(&mut self, value:TailEnd) {
+    pub fn set_tail_end(&mut self, value: TailEnd) {
         self.tail_end = Some(value);
     }
 
@@ -95,7 +95,7 @@ impl Outline {
         &mut self.no_fill
     }
 
-    pub fn set_no_fill(&mut self, value:NoFill) -> &mut Outline {
+    pub fn set_no_fill(&mut self, value: NoFill) -> &mut Outline {
         self.no_fill = Some(value);
         self
     }
@@ -108,7 +108,7 @@ impl Outline {
         &mut self.bevel
     }
 
-    pub fn set_bevel(&mut self, value:Bevel) -> &mut Outline {
+    pub fn set_bevel(&mut self, value: Bevel) -> &mut Outline {
         self.bevel = Some(value);
         self
     }
@@ -121,7 +121,7 @@ impl Outline {
         &mut self.preset_dash
     }
 
-    pub fn set_preset_dash(&mut self, value:PresetDash) -> &mut Outline {
+    pub fn set_preset_dash(&mut self, value: PresetDash) -> &mut Outline {
         self.preset_dash = Some(value);
         self
     }
@@ -134,87 +134,87 @@ impl Outline {
         &mut self.miter
     }
 
-    pub fn set_miter(&mut self, value:Miter) -> &mut Outline {
+    pub fn set_miter(&mut self, value: Miter) -> &mut Outline {
         self.miter = Some(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        e:&BytesStart
+        reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         let mut buf = Vec::new();
-    
+
         match get_attribute(e, b"w") {
-            Some(v) => {&mut self.set_width(v.parse::<u32>().unwrap());},
+            Some(v) => {
+                &mut self.set_width(v.parse::<u32>().unwrap());
+            }
             None => {}
         }
-    
+
         match get_attribute(e, b"cap") {
-            Some(v) => {&mut self.set_cap_type(v);},
+            Some(v) => {
+                &mut self.set_cap_type(v);
+            }
             None => {}
         }
 
         match get_attribute(e, b"cmpd") {
-            Some(v) => {&mut self.set_compound_line_type(v);},
+            Some(v) => {
+                &mut self.set_compound_line_type(v);
+            }
             None => {}
         }
 
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"a:solidFill" => {
-                            let mut solid_fill = SolidFill::default();
-                            solid_fill.set_attributes(reader, e);
-                            &mut self.set_solid_fill(solid_fill);
-                        },
-                        b"a:gradFill" => {
-                            let mut obj = GradientFill::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_gradient_fill(obj);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"a:solidFill" => {
+                        let mut solid_fill = SolidFill::default();
+                        solid_fill.set_attributes(reader, e);
+                        &mut self.set_solid_fill(solid_fill);
                     }
+                    b"a:gradFill" => {
+                        let mut obj = GradientFill::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_gradient_fill(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::Empty(ref e)) => {
-                    match e.name() {
-                        b"a:tailEnd" => {
-                            let mut obj = TailEnd::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_tail_end(obj);
-                        },
-                        b"a:noFill" => {
-                            let mut obj = NoFill::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_no_fill(obj);
-                        },
-                        b"a:bevel" => {
-                            let mut obj = Bevel::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_bevel(obj);
-                        },
-                        b"a:miter" => {
-                            let mut obj = Miter::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_miter(obj);
-                        },
-                        b"a:prstDash" => {
-                            let mut obj = PresetDash::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_preset_dash(obj);
-                        },
-                        _ => (),
+                Ok(Event::Empty(ref e)) => match e.name() {
+                    b"a:tailEnd" => {
+                        let mut obj = TailEnd::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_tail_end(obj);
                     }
+                    b"a:noFill" => {
+                        let mut obj = NoFill::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_no_fill(obj);
+                    }
+                    b"a:bevel" => {
+                        let mut obj = Bevel::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_bevel(obj);
+                    }
+                    b"a:miter" => {
+                        let mut obj = Miter::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_miter(obj);
+                    }
+                    b"a:prstDash" => {
+                        let mut obj = PresetDash::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_preset_dash(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"a:ln" => {
-                            return;
-                        },
-                        _ => (),
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"a:ln" => {
+                        return;
                     }
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "a:ln"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -235,56 +235,56 @@ impl Outline {
             Some(v) => {
                 attributes.push(("cap", v));
             }
-            None => {},
+            None => {}
         }
         match &self.compound_line_type {
             Some(v) => {
                 attributes.push(("cmpd", v));
             }
-            None => {},
+            None => {}
         }
         write_start_tag(writer, "a:ln", attributes, false);
 
         // a:solidFill
         match &self.solid_fill {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:gradFill
         match &self.gradient_fill {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:tailEnd
         match &self.tail_end {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:noFill
         match &self.no_fill {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:bevel
         match &self.bevel {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:miter
         match &self.miter {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         // a:prstDash
         match &self.preset_dash {
             Some(v) => v.write_to(writer),
-            None => {},
+            None => {}
         }
 
         write_end_tag(writer, "a:ln");
