@@ -1,11 +1,11 @@
 // a:prstGeom
 use super::adjust_value_list::AdjustValueList;
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct PresetGeometry {
@@ -206,7 +206,7 @@ impl PresetGeometry {
         &self.geometry
     }
 
-    pub fn set_geometry<S: Into<String>>(&mut self, value:S) {
+    pub fn set_geometry<S: Into<String>>(&mut self, value: S) {
         self.geometry = value.into();
     }
 
@@ -218,35 +218,31 @@ impl PresetGeometry {
         &mut self.adjust_value_list
     }
 
-    pub fn set_adjust_value_list(&mut self, value:AdjustValueList) {
+    pub fn set_adjust_value_list(&mut self, value: AdjustValueList) {
         self.adjust_value_list = value;
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        e:&BytesStart
+        reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         &mut self.set_geometry(get_attribute(e, b"prst").unwrap());
 
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"a:avLst" => {
-                            &mut self.get_adjust_value_list_mut().set_attributes(reader, e);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"a:avLst" => {
+                        &mut self.get_adjust_value_list_mut().set_attributes(reader, e);
                     }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"a:prstGeom" => {
-                            return;
-                        },
-                        _ => (),
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"a:prstGeom" => {
+                        return;
                     }
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "a:prstGeom"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -258,13 +254,11 @@ impl PresetGeometry {
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // a:prstGeom
-        write_start_tag(writer, "a:prstGeom", vec![
-            ("prst", &self.geometry),
-        ], false);
-    
+        write_start_tag(writer, "a:prstGeom", vec![("prst", &self.geometry)], false);
+
         // a:avLst
         &self.adjust_value_list.write_to(writer);
-    
+
         write_end_tag(writer, "a:prstGeom");
     }
 }
