@@ -1,20 +1,20 @@
-use super::TextCharacterPropertiesType;
-use super::TextCapsValues;
 use super::super::EnumValue;
 use super::super::Int32Value;
-use super::SolidFill;
-use super::Outline;
-use super::LatinFont;
 use super::EastAsianFont;
-use super::GradientFill;
-use super::NoFill;
 use super::EffectList;
-use writer::driver::*;
-use reader::driver::*;
+use super::GradientFill;
+use super::LatinFont;
+use super::NoFill;
+use super::Outline;
+use super::SolidFill;
+use super::TextCapsValues;
+use super::TextCharacterPropertiesType;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct RunProperties {
@@ -40,7 +40,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.text
     }
 
-    fn set_text<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_text<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.text = value.into();
         self
     }
@@ -49,7 +49,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.kumimoji
     }
 
-    fn set_kumimoji<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_kumimoji<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.kumimoji = Some(value.into());
         self
     }
@@ -58,7 +58,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.language
     }
 
-    fn set_language<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_language<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.language = Some(value.into());
         self
     }
@@ -67,7 +67,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.alternative_language
     }
 
-    fn set_alternative_language<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_alternative_language<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.alternative_language = Some(value.into());
         self
     }
@@ -76,7 +76,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.bold
     }
 
-    fn set_bold<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_bold<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.bold = Some(value.into());
         self
     }
@@ -85,7 +85,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.sz
     }
 
-    fn set_sz<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_sz<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.sz = Some(value.into());
         self
     }
@@ -94,7 +94,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.italic
     }
 
-    fn set_italic<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    fn set_italic<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.italic = Some(value.into());
         self
     }
@@ -103,7 +103,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.capital.get_value()
     }
 
-    fn set_capital(&mut self, value:TextCapsValues) -> &mut Self {
+    fn set_capital(&mut self, value: TextCapsValues) -> &mut Self {
         self.capital.set_value(value);
         self
     }
@@ -112,7 +112,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &self.spacing.get_value()
     }
 
-    fn set_spacing(&mut self, value:i32) -> &mut Self {
+    fn set_spacing(&mut self, value: i32) -> &mut Self {
         self.spacing.set_value(value);
         self
     }
@@ -124,8 +124,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_solid_fill_mut(&mut self) -> &mut Option<SolidFill> {
         &mut self.solid_fill
     }
-    
-    fn set_solid_fill(&mut self, value:SolidFill) -> &mut Self {
+
+    fn set_solid_fill(&mut self, value: SolidFill) -> &mut Self {
         self.solid_fill = Some(value);
         self
     }
@@ -138,7 +138,7 @@ impl TextCharacterPropertiesType for RunProperties {
         &mut self.outline
     }
 
-    fn set_outline(&mut self, value:Outline) -> &mut Self {
+    fn set_outline(&mut self, value: Outline) -> &mut Self {
         self.outline = Some(value);
         self
     }
@@ -150,8 +150,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_latin_font_mut(&mut self) -> &mut Option<LatinFont> {
         &mut self.latin_font
     }
-    
-    fn set_latin_font(&mut self, value:LatinFont) -> &mut Self {
+
+    fn set_latin_font(&mut self, value: LatinFont) -> &mut Self {
         self.latin_font = Some(value);
         self
     }
@@ -163,8 +163,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_east_asian_font_mut(&mut self) -> &mut Option<EastAsianFont> {
         &mut self.east_asian_font
     }
-    
-    fn set_east_asian_font(&mut self, value:EastAsianFont) -> &mut Self {
+
+    fn set_east_asian_font(&mut self, value: EastAsianFont) -> &mut Self {
         self.east_asian_font = Some(value);
         self
     }
@@ -176,8 +176,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_gradient_fill_mut(&mut self) -> &mut Option<GradientFill> {
         &mut self.gradient_fill
     }
-    
-    fn set_gradient_fill(&mut self, value:GradientFill) -> &mut Self {
+
+    fn set_gradient_fill(&mut self, value: GradientFill) -> &mut Self {
         self.gradient_fill = Some(value);
         self
     }
@@ -189,8 +189,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_no_fill_mut(&mut self) -> &mut Option<NoFill> {
         &mut self.no_fill
     }
-    
-    fn set_no_fill(&mut self, value:NoFill) -> &mut Self {
+
+    fn set_no_fill(&mut self, value: NoFill) -> &mut Self {
         self.no_fill = Some(value);
         self
     }
@@ -202,8 +202,8 @@ impl TextCharacterPropertiesType for RunProperties {
     fn get_effect_list_mut(&mut self) -> &mut Option<EffectList> {
         &mut self.effect_list
     }
-    
-    fn set_effect_list(&mut self, value:EffectList) -> &mut Self {
+
+    fn set_effect_list(&mut self, value: EffectList) -> &mut Self {
         self.effect_list = Some(value);
         self
     }
@@ -212,40 +212,56 @@ impl TextCharacterPropertiesType for RunProperties {
 impl RunProperties {
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        e:&BytesStart,
-        empty_flag:bool,
+        reader: &mut Reader<R>,
+        e: &BytesStart,
+        empty_flag: bool,
     ) {
         match get_attribute(e, b"kumimoji") {
-            Some(v) => {&mut self.set_kumimoji(v);},
+            Some(v) => {
+                &mut self.set_kumimoji(v);
+            }
             None => {}
         }
         match get_attribute(e, b"lang") {
-            Some(v) => {&mut self.set_language(v);},
+            Some(v) => {
+                &mut self.set_language(v);
+            }
             None => {}
         }
         match get_attribute(e, b"altLang") {
-            Some(v) => {&mut self.set_alternative_language(v);},
+            Some(v) => {
+                &mut self.set_alternative_language(v);
+            }
             None => {}
         }
         match get_attribute(e, b"b") {
-            Some(v) => {&mut self.set_bold(v);},
+            Some(v) => {
+                &mut self.set_bold(v);
+            }
             None => {}
         }
         match get_attribute(e, b"sz") {
-            Some(v) => {&mut self.set_sz(v);},
+            Some(v) => {
+                &mut self.set_sz(v);
+            }
             None => {}
         }
         match get_attribute(e, b"i") {
-            Some(v) => {&mut self.set_italic(v);},
+            Some(v) => {
+                &mut self.set_italic(v);
+            }
             None => {}
         }
         match get_attribute(e, b"cap") {
-            Some(v) => {&mut self.capital.set_value_string(v);},
+            Some(v) => {
+                &mut self.capital.set_value_string(v);
+            }
             None => {}
         }
         match get_attribute(e, b"spc") {
-            Some(v) => {&mut self.spacing.set_value_string(v);},
+            Some(v) => {
+                &mut self.spacing.set_value_string(v);
+            }
             None => {}
         }
 
@@ -256,61 +272,55 @@ impl RunProperties {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"a:solidFill" => {
-                            let mut obj = SolidFill::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_solid_fill(obj);
-                        },
-                        b"a:ln" => {
-                            let mut obj = Outline::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_outline(obj);
-                        },
-                        b"a:gradFill" => {
-                            let mut obj = GradientFill::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_gradient_fill(obj);
-                        },
-                        b"a:effectLst" => {
-                            let mut effect_list = EffectList::default();
-                            effect_list.set_attributes(reader, e, false);
-                            &mut self.set_effect_list(effect_list);
-                        }
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"a:solidFill" => {
+                        let mut obj = SolidFill::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_solid_fill(obj);
                     }
+                    b"a:ln" => {
+                        let mut obj = Outline::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_outline(obj);
+                    }
+                    b"a:gradFill" => {
+                        let mut obj = GradientFill::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_gradient_fill(obj);
+                    }
+                    b"a:effectLst" => {
+                        let mut effect_list = EffectList::default();
+                        effect_list.set_attributes(reader, e, false);
+                        &mut self.set_effect_list(effect_list);
+                    }
+                    _ => (),
                 },
-                Ok(Event::Empty(ref e)) => {
-                    match e.name() {
-                        b"a:latin" => {
-                            let mut obj = LatinFont::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_latin_font(obj);
-                        },
-                        b"a:ea" => {
-                            let mut obj = EastAsianFont::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_east_asian_font(obj);
-                        },
-                        b"a:noFill" => {
-                            let mut obj = NoFill::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_no_fill(obj);
-                        }
-                        b"a:effectLst" => {
-                            let mut obj = EffectList::default();
-                            obj.set_attributes(reader, e, true);
-                            &mut self.set_effect_list(obj);
-                        }
-                        _ => (),
+                Ok(Event::Empty(ref e)) => match e.name() {
+                    b"a:latin" => {
+                        let mut obj = LatinFont::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_latin_font(obj);
                     }
+                    b"a:ea" => {
+                        let mut obj = EastAsianFont::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_east_asian_font(obj);
+                    }
+                    b"a:noFill" => {
+                        let mut obj = NoFill::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_no_fill(obj);
+                    }
+                    b"a:effectLst" => {
+                        let mut obj = EffectList::default();
+                        obj.set_attributes(reader, e, true);
+                        &mut self.set_effect_list(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"a:rPr" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"a:rPr" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "a:rPr"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -352,48 +362,68 @@ impl RunProperties {
         if self.spacing.has_value() == true {
             attributes.push(("spc", self.spacing.get_value_string()));
         }
-        if self.solid_fill.is_some() || self.outline.is_some() || self.latin_font.is_some() || self.east_asian_font.is_some() || self.gradient_fill.is_some() || self.effect_list.is_some() {
+        if self.solid_fill.is_some()
+            || self.outline.is_some()
+            || self.latin_font.is_some()
+            || self.east_asian_font.is_some()
+            || self.gradient_fill.is_some()
+            || self.effect_list.is_some()
+        {
             write_start_tag(writer, "a:rPr", attributes, false);
 
             // a:solidFill
             match &self.solid_fill {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
             // a:ln
             match &self.outline {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
-    
+
             // a:latin
             match &self.latin_font {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
             // a:ea
             match &self.east_asian_font {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
             // a:gradFill
             match &self.gradient_fill {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
             // a:noFill
             match &self.no_fill {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
             // a:effectLst
             match &self.effect_list {
-                Some(v) => {v.write_to(writer);},
+                Some(v) => {
+                    v.write_to(writer);
+                }
                 None => {}
             }
 
@@ -402,4 +432,4 @@ impl RunProperties {
             write_start_tag(writer, "a:rPr", attributes, true);
         }
     }
-}
\ No newline at end of file
+}
