@@ -1,11 +1,11 @@
 // a:solidFill
-use super::scheme_color::SchemeColor;
 use super::rgb_color_model_hex::RgbColorModelHex;
-use writer::driver::*;
+use super::scheme_color::SchemeColor;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct SolidFill {
@@ -21,7 +21,7 @@ impl SolidFill {
         &mut self.scheme_color
     }
 
-    pub fn set_scheme_color(&mut self, value:SchemeColor) {
+    pub fn set_scheme_color(&mut self, value: SchemeColor) {
         self.scheme_color = Some(value);
     }
 
@@ -32,56 +32,50 @@ impl SolidFill {
     pub fn get_rgb_color_model_hex_mut(&mut self) -> &mut Option<RgbColorModelHex> {
         &mut self.rgb_color_model_hex
     }
-    
-    pub fn set_rgb_color_model_hex(&mut self, value:RgbColorModelHex) {
+
+    pub fn set_rgb_color_model_hex(&mut self, value: RgbColorModelHex) {
         self.rgb_color_model_hex = Some(value);
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        _e:&BytesStart
+        reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"a:schemeClr" => {
-                            let mut scheme_color = SchemeColor::default();
-                            scheme_color.set_attributes(reader, e, false);
-                            &mut self.set_scheme_color(scheme_color);
-                        },
-                        b"a:srgbClr" => {
-                            let mut rgb_color_model_hex = RgbColorModelHex::default();
-                            rgb_color_model_hex.set_attributes(reader, e, false);
-                            &mut self.set_rgb_color_model_hex(rgb_color_model_hex);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"a:schemeClr" => {
+                        let mut scheme_color = SchemeColor::default();
+                        scheme_color.set_attributes(reader, e, false);
+                        &mut self.set_scheme_color(scheme_color);
                     }
+                    b"a:srgbClr" => {
+                        let mut rgb_color_model_hex = RgbColorModelHex::default();
+                        rgb_color_model_hex.set_attributes(reader, e, false);
+                        &mut self.set_rgb_color_model_hex(rgb_color_model_hex);
+                    }
+                    _ => (),
                 },
-                Ok(Event::Empty(ref e)) => {
-                    match e.name() {
-                        b"a:schemeClr" => {
-                            let mut scheme_color = SchemeColor::default();
-                            scheme_color.set_attributes(reader, e, true);
-                            &mut self.set_scheme_color(scheme_color);
-                        },
-                        b"a:srgbClr" => {
-                            let mut rgb_color_model_hex = RgbColorModelHex::default();
-                            rgb_color_model_hex.set_attributes(reader, e, true);
-                            &mut self.set_rgb_color_model_hex(rgb_color_model_hex);
-                        },
-                        _ => (),
+                Ok(Event::Empty(ref e)) => match e.name() {
+                    b"a:schemeClr" => {
+                        let mut scheme_color = SchemeColor::default();
+                        scheme_color.set_attributes(reader, e, true);
+                        &mut self.set_scheme_color(scheme_color);
                     }
+                    b"a:srgbClr" => {
+                        let mut rgb_color_model_hex = RgbColorModelHex::default();
+                        rgb_color_model_hex.set_attributes(reader, e, true);
+                        &mut self.set_rgb_color_model_hex(rgb_color_model_hex);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"a:solidFill" => {
-                            return;
-                        },
-                        _ => (),
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"a:solidFill" => {
+                        return;
                     }
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "a:solidFill"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -97,13 +91,13 @@ impl SolidFill {
         match &self.scheme_color {
             Some(color) => {
                 color.write_to(writer);
-            },
+            }
             None => {}
         }
         match &self.rgb_color_model_hex {
             Some(hex) => {
                 hex.write_to(writer);
-            },
+            }
             None => {}
         }
         write_end_tag(writer, "a:solidFill");
