@@ -3,11 +3,11 @@ use super::NonVisualShapeProperties;
 use super::ShapeProperties;
 use super::ShapeStyle;
 use super::TextBody;
-use writer::driver::*;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Shape {
@@ -26,7 +26,7 @@ impl Shape {
         &mut self.anchor
     }
 
-    pub fn set_anchor(&mut self, value:Anchor) {
+    pub fn set_anchor(&mut self, value: Anchor) {
         self.anchor = value;
     }
 
@@ -38,7 +38,7 @@ impl Shape {
         &mut self.non_visual_shape_properties
     }
 
-    pub fn set_non_visual_shape_properties(&mut self, value:NonVisualShapeProperties) {
+    pub fn set_non_visual_shape_properties(&mut self, value: NonVisualShapeProperties) {
         self.non_visual_shape_properties = value;
     }
 
@@ -50,7 +50,7 @@ impl Shape {
         &mut self.shape_properties
     }
 
-    pub fn set_shape_properties(&mut self, value:ShapeProperties) {
+    pub fn set_shape_properties(&mut self, value: ShapeProperties) {
         self.shape_properties = value;
     }
 
@@ -62,7 +62,7 @@ impl Shape {
         &mut self.shape_style
     }
 
-    pub fn set_shape_style(&mut self, value:ShapeStyle) {
+    pub fn set_shape_style(&mut self, value: ShapeStyle) {
         self.shape_style = Some(value);
     }
 
@@ -74,40 +74,40 @@ impl Shape {
         &mut self.text_body
     }
 
-    pub fn set_text_body(&mut self, value:TextBody) {
+    pub fn set_text_body(&mut self, value: TextBody) {
         self.text_body = Some(value);
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        _e:&BytesStart
+        reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"xdr:nvSpPr" => { &mut self.non_visual_shape_properties.set_attributes(reader, e); }
-                        b"xdr:spPr" => { &mut self.shape_properties.set_attributes(reader, e); },
-                        b"xdr:style" => {
-                            let mut obj = ShapeStyle::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_shape_style(obj);
-                        },
-                        b"xdr:txBody" => {
-                            let mut obj = TextBody::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_text_body(obj);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"xdr:nvSpPr" => {
+                        &mut self.non_visual_shape_properties.set_attributes(reader, e);
                     }
+                    b"xdr:spPr" => {
+                        &mut self.shape_properties.set_attributes(reader, e);
+                    }
+                    b"xdr:style" => {
+                        let mut obj = ShapeStyle::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_shape_style(obj);
+                    }
+                    b"xdr:txBody" => {
+                        let mut obj = TextBody::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_text_body(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"xdr:sp" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"xdr:sp" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "xdr:sp"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -119,10 +119,12 @@ impl Shape {
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>, ole_id: &usize) {
         // xdr:sp
-        write_start_tag(writer, "xdr:sp", vec![
-            ("macro", ""),
-            ("textlink", ""),
-        ], false);
+        write_start_tag(
+            writer,
+            "xdr:sp",
+            vec![("macro", ""), ("textlink", "")],
+            false,
+        );
 
         // xdr:nvSpPr
         &self.non_visual_shape_properties.write_to(writer, ole_id);
@@ -132,14 +134,18 @@ impl Shape {
 
         // xdr:style
         match &self.shape_style {
-            Some(v) => {v.write_to(writer);},
-            None => {},
+            Some(v) => {
+                v.write_to(writer);
+            }
+            None => {}
         }
 
         // xdr:txBody
         match &self.text_body {
-            Some(v) => {v.write_to(writer);},
-            None => {},
+            Some(v) => {
+                v.write_to(writer);
+            }
+            None => {}
         }
 
         write_end_tag(writer, "xdr:sp");
