@@ -1,10 +1,10 @@
-use structs::StringValue;
-use quick_xml::events::{BytesStart};
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
 use quick_xml::Writer;
-use std::io::Cursor;
-use writer::driver::*;
 use reader::driver::*;
+use std::io::Cursor;
+use structs::StringValue;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Fill {
@@ -15,7 +15,7 @@ impl Fill {
         &self.color_2.get_value()
     }
 
-    pub fn set_color_2<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    pub fn set_color_2<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.color_2.set_value(value);
         self
     }
@@ -28,18 +28,18 @@ impl Fill {
         match get_attribute(e, b"color2") {
             Some(v) => {
                 self.color_2.set_value_string(v);
-            },
-            None => {},
+            }
+            None => {}
         }
     }
 
-    pub(crate) fn write_to(
-        &self,
-        writer: &mut Writer<Cursor<Vec<u8>>>,
-    ) {
+    pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // v:fill
-        write_start_tag(writer, "v:fill", vec![
-            ("color2", &self.color_2.get_value()),
-        ], true);
+        write_start_tag(
+            writer,
+            "v:fill",
+            vec![("color2", &self.color_2.get_value())],
+            true,
+        );
     }
 }
