@@ -1,10 +1,10 @@
-use structs::drawing::charts::ChartSpace;
-use structs::Spreadsheet;
-use quick_xml::events::{Event, BytesDecl};
-use quick_xml::Writer;
-use std::io;
 use super::driver::*;
 use super::XlsxError;
+use quick_xml::events::{BytesDecl, Event};
+use quick_xml::Writer;
+use std::io;
+use structs::drawing::charts::ChartSpace;
+use structs::Spreadsheet;
 
 const SUB_DIR: &'static str = "xl/charts";
 
@@ -18,7 +18,11 @@ pub(crate) fn write<W: io::Seek + io::Write>(
 
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
-    let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
+    let _ = writer.write_event(Event::Decl(BytesDecl::new(
+        b"1.0",
+        Some(b"UTF-8"),
+        Some(b"yes"),
+    )));
     write_new_line(&mut writer);
 
     // c:chartSpace
