@@ -1,22 +1,42 @@
-use quick_xml::events::{Event, BytesDecl};
+use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
 use std::io;
 
-use ::structs::Spreadsheet;
 use super::driver::*;
 use super::XlsxError;
+use structs::Spreadsheet;
 
-pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mut zip::ZipWriter<W>, sub_dir: &str, file_name: &str) -> Result<(), XlsxError> {
+pub(crate) fn write<W: io::Seek + io::Write>(
+    spreadsheet: &Spreadsheet,
+    arv: &mut zip::ZipWriter<W>,
+    sub_dir: &str,
+    file_name: &str,
+) -> Result<(), XlsxError> {
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
-    let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
+    let _ = writer.write_event(Event::Decl(BytesDecl::new(
+        b"1.0",
+        Some(b"UTF-8"),
+        Some(b"yes"),
+    )));
     write_new_line(&mut writer);
 
     // Properties
-    write_start_tag(&mut writer, "Properties", vec![
-        ("xmlns", "http://schemas.openxmlformats.org/officeDocument/2006/extended-properties"),
-        ("xmlns:vt", "http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes"),
-    ], false);
+    write_start_tag(
+        &mut writer,
+        "Properties",
+        vec![
+            (
+                "xmlns",
+                "http://schemas.openxmlformats.org/officeDocument/2006/extended-properties",
+            ),
+            (
+                "xmlns:vt",
+                "http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes",
+            ),
+        ],
+        false,
+    );
 
     // Application
     write_start_tag(&mut writer, "Application", vec![], false);
@@ -37,10 +57,12 @@ pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mu
     write_start_tag(&mut writer, "HeadingPairs", vec![], false);
 
     // vt:vector
-    write_start_tag(&mut writer, "vt:vector", vec![
-        ("size", "2"),
-        ("baseType", "variant"),
-    ], false);
+    write_start_tag(
+        &mut writer,
+        "vt:vector",
+        vec![("size", "2"), ("baseType", "variant")],
+        false,
+    );
 
     // vt:variant
     write_start_tag(&mut writer, "vt:variant", vec![], false);
@@ -57,7 +79,10 @@ pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mu
 
     // vt:i4
     write_start_tag(&mut writer, "vt:i4", vec![], false);
-    write_text_node(&mut writer, spreadsheet.get_sheet_count().to_string().as_str());
+    write_text_node(
+        &mut writer,
+        spreadsheet.get_sheet_count().to_string().as_str(),
+    );
     write_end_tag(&mut writer, "vt:i4");
 
     write_end_tag(&mut writer, "vt:variant");
@@ -70,12 +95,17 @@ pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mu
     write_start_tag(&mut writer, "TitlesOfParts", vec![], false);
 
     // vt:vector
-    write_start_tag(&mut writer, "vt:vector", vec![
-        ("size", spreadsheet.get_sheet_count().to_string().as_str()),
-        ("baseType", "lpstr"),
-    ], false);
+    write_start_tag(
+        &mut writer,
+        "vt:vector",
+        vec![
+            ("size", spreadsheet.get_sheet_count().to_string().as_str()),
+            ("baseType", "lpstr"),
+        ],
+        false,
+    );
 
-    for workseet in spreadsheet.get_sheet_collection(){
+    for workseet in spreadsheet.get_sheet_collection() {
         // vt:lpstr
         write_start_tag(&mut writer, "vt:lpstr", vec![], false);
         write_text_node(&mut writer, workseet.get_title());
@@ -119,4 +149,4 @@ pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mu
     write_end_tag(&mut writer, "Properties");
     let _ = make_file_from_writer(&file_name, arv, writer, Some(sub_dir)).unwrap();
     Ok(())
-}
\ No newline at end of file
+}
