@@ -1,10 +1,10 @@
-use quick_xml::events::{Event, BytesDecl};
+use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
 use std::io;
 
-use ::structs::Worksheet;
 use super::driver::*;
 use super::XlsxError;
+use structs::Worksheet;
 
 const SUB_DIR: &'static str = "xl/drawings/_rels";
 
@@ -12,21 +12,30 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     worksheet: &Worksheet,
     drawing_id: &usize,
     chart_start_id: &usize,
-    arv: &mut zip::ZipWriter<W>
-) -> Result<(), XlsxError> 
-{
+    arv: &mut zip::ZipWriter<W>,
+) -> Result<(), XlsxError> {
     let file_name = format!("drawing{}.xml.rels", drawing_id);
     let mut is_write = false;
 
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
-    let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
+    let _ = writer.write_event(Event::Decl(BytesDecl::new(
+        b"1.0",
+        Some(b"UTF-8"),
+        Some(b"yes"),
+    )));
     write_new_line(&mut writer);
 
     // relationships
-    write_start_tag(&mut writer, "Relationships", vec![
-        ("xmlns", "http://schemas.openxmlformats.org/package/2006/relationships"),
-    ], false);
+    write_start_tag(
+        &mut writer,
+        "Relationships",
+        vec![(
+            "xmlns",
+            "http://schemas.openxmlformats.org/package/2006/relationships",
+        )],
+        false,
+    );
 
     let mut r_id = 1;
     let mut chart_id = chart_start_id.clone();
@@ -36,23 +45,34 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             &r_id,
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart",
             format!("../charts/chart{}.xml", chart_id).as_str(),
-            ""
+            "",
         );
         r_id += 1;
         chart_id += 1;
     }
-    for two_cell_anchor in worksheet.get_worksheet_drawing().get_two_cell_anchor_collection() {
+    for two_cell_anchor in worksheet
+        .get_worksheet_drawing()
+        .get_two_cell_anchor_collection()
+    {
         match two_cell_anchor.get_picture() {
             Some(picture) => {
                 is_write = write_relationship(
                     &mut writer,
                     &r_id,
                     "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",
-                    format!("../media/{}", picture.get_blip_fill().get_blip().get_image().get_image_name()).as_str(),
-                    ""
+                    format!(
+                        "../media/{}",
+                        picture
+                            .get_blip_fill()
+                            .get_blip()
+                            .get_image()
+                            .get_image_name()
+                    )
+                    .as_str(),
+                    "",
                 );
                 r_id += 1;
-            },
+            }
             None => {}
         }
     }
@@ -65,8 +85,13 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     Ok(())
 }
 
-fn write_relationship(writer: &mut Writer<io::Cursor<Vec<u8>>>, r_id: &i32, p_type: &str, p_target: &str, p_target_mode: &str) -> bool
-{
+fn write_relationship(
+    writer: &mut Writer<io::Cursor<Vec<u8>>>,
+    r_id: &i32,
+    p_type: &str,
+    p_target: &str,
+    p_target_mode: &str,
+) -> bool {
     let tag_name = "Relationship";
     let r_id_str = format!("rId{}", r_id);
     let mut attributes: Vec<(&str, &str)> = Vec::new();
@@ -78,4 +103,4 @@ fn write_relationship(writer: &mut Writer<io::Cursor<Vec<u8>>>, r_id: &i32, p_ty
     }
     write_start_tag(writer, tag_name, attributes, true);
     true
-}
\ No newline at end of file
+}
