@@ -2,8 +2,8 @@ use super::driver::*;
 use super::XlsxError;
 use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
-use std::collections::BTreeSet;
 use std::io;
+use structs::Cell;
 use structs::SharedStringTable;
 use structs::Spreadsheet;
 use structs::Stylesheet;
@@ -102,11 +102,6 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         //    ("summaryRight", if worksheet.show_summary_right {"1"} else {"0"}),
         //], true);
 
-        // pageSetUpPr
-        if worksheet.get_page_setup().get_fit_to_page() == &true {
-            write_start_tag(&mut writer, "pageSetUpPr", vec![("fitToPage", "1")], true);
-        }
-
         // dimension
         write_start_tag(
             &mut writer,
@@ -139,44 +134,89 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         );
 
         // cols
-        worksheet.get_column_dimensions_crate().write_to(
-            &mut writer,
-            stylesheet,
+        let mut column_dimensions = worksheet.get_column_dimensions_crate().clone();
+        column_dimensions.calculation_auto_width(
             worksheet.get_cell_collection_crate(),
+            worksheet.get_merge_cells_crate(),
         );
+        column_dimensions.write_to(&mut writer, stylesheet);
 
         // sheetData
         let has_sheet_data = worksheet.get_row_dimensions().len() > 0;
         write_start_tag(&mut writer, "sheetData", vec![], !has_sheet_data);
 
-        for (row_num, row) in worksheet.get_row_dimensions_to_b_tree_map() {
-            // cells
-            let cells = worksheet.get_collection_by_row(&row_num);
-            let mut col_num_list: BTreeSet<u32> = BTreeSet::new();
-            for (col_num, _) in &cells {
-                col_num_list.insert(col_num.clone());
+        // row dimensions sort.
+        let mut row_dimensions = worksheet.get_row_dimensions().clone();
+        row_dimensions.sort_by(|a, b| a.get_row_num().cmp(&b.get_row_num()));
+        // cells sort.
+        let mut cells = worksheet.get_cell_collection().clone();
+        cells.sort_by(|a, b| {
+            (
+                a.get_coordinate().get_row_num(),
+                a.get_coordinate().get_col_num(),
+            )
+                .cmp(&(
+                    b.get_coordinate().get_row_num(),
+                    b.get_coordinate().get_col_num(),
+                ))
+        });
+        let mut cells_iter = cells.iter();
+        // row loop
+        let mut is_cells_active = true;
+        let mut cell_bk: Option<&Cell> = None;
+        for row in &row_dimensions {
+            let mut do_next_cells = true;
+            let mut cells_in_row: Vec<&Cell> = Vec::new();
+            if cell_bk.is_some() {
+                if row.get_row_num() == cell_bk.unwrap().get_coordinate().get_row_num() {
+                    cells_in_row.push(cell_bk.unwrap());
+                    cell_bk = None;
+                } else {
+                    do_next_cells = false;
+                }
+            }
+            if is_cells_active && do_next_cells {
+                'cell_loop: loop {
+                    let cell_raw = cells_iter.next();
+                    if cell_raw.is_none() {
+                        is_cells_active = false;
+                        break 'cell_loop;
+                    }
+                    cell_bk = Some(cell_raw.unwrap());
+                    if row.get_row_num() == cell_bk.unwrap().get_coordinate().get_row_num() {
+                        cells_in_row.push(cell_bk.unwrap());
+                        cell_bk = None;
+                    } else {
+                        break 'cell_loop;
+                    }
+                }
             }
 
             // row
-            let include_cell = col_num_list.len() > 0;
-            let fist_num = match col_num_list.iter().next() {
-                Some(col_num) => col_num,
-                None => &0u32,
-            };
-            let last_num = match col_num_list.iter().last() {
-                Some(col_num) => col_num,
-                None => &0u32,
-            };
-            let spans = format!("{}:{}", fist_num, last_num);
-            row.write_to(&mut writer, stylesheet, spans, !include_cell);
-
-            // c
-            for (_, cell) in cells {
-                cell.write_to(&mut writer, shared_string_table, stylesheet);
-            }
-
+            let include_cell = cells_in_row.len() > 0;
             if include_cell {
+                let fist_num = cells_in_row
+                    .iter()
+                    .next()
+                    .unwrap()
+                    .get_coordinate()
+                    .get_col_num();
+                let last_num = cells_in_row
+                    .iter()
+                    .last()
+                    .unwrap()
+                    .get_coordinate()
+                    .get_col_num();
+                let spans = format!("{}:{}", fist_num, last_num);
+                row.write_to(&mut writer, stylesheet, spans, false);
+                // c
+                for cell in cells_in_row {
+                    cell.write_to(&mut writer, shared_string_table, stylesheet);
+                }
                 write_end_tag(&mut writer, "row");
+            } else {
+                let spans = format!("{}:{}", 0, 0);
+                row.write_to(&mut writer, stylesheet, spans, true);
             }
         }
 
@@ -197,35 +237,11 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             None => {}
         };
 
-        if worksheet.get_merge_cells().len() > 0 {
-            // mergeCells
-            write_start_tag(
-                &mut writer,
-                "mergeCells",
-                vec![(
-                    "count",
-                    worksheet.get_merge_cells().len().to_string().as_str(),
-                )],
-                false,
-            );
-
-            // mergeCell
-            for merge_cell in worksheet.get_merge_cells() {
-                write_start_tag(
-                    &mut writer,
-                    "mergeCell",
-                    vec![("ref", merge_cell.get_range().as_str())],
-                    true,
-                );
-            }
-
-            write_end_tag(&mut writer, "mergeCells");
-        }
+        // mergeCells
+        worksheet.get_merge_cells_crate().write_to(&mut writer);
 
         // phoneticPr
-        //write_start_tag(&mut writer, "phoneticPr", vec![
-        //    ("fontId", "1"),
-        //], true);
+        write_start_tag(&mut writer, "phoneticPr", vec![("fontId", "1")], true);
 
         // conditionalFormatting
         for conditional_formatting in worksheet.get_conditional_styles_collection() {
@@ -319,11 +335,11 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         let mut r_id = 1;
 
         // hyperlinks
-        if worksheet.get_hyperlink_collection().len() > 0 {
+        if worksheet.has_hyperlink() {
             write_start_tag(&mut writer, "hyperlinks", vec![], false);
 
             // hyperlink
-            for (coordition, hyperlink) in worksheet.get_hyperlink_collection() {
+            for (coordition, hyperlink) in worksheet.get_hyperlink_collection_to_hashmap() {
                 let r_id_str = format!("rId{}", &r_id);
                 let mut attributes: Vec<(&str, &str)> = Vec::new();
                 attributes.push(("ref", &coordition));
@@ -339,29 +355,26 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             write_end_tag(&mut writer, "hyperlinks");
         }
 
+        // printOptions
+        worksheet.get_print_options().write_to(&mut writer);
+
         // pageMargins
-        write_start_tag(
-            &mut writer,
-            "pageMargins",
-            vec![
-                ("left", "0.7"),
-                ("right", "0.7"),
-                ("top", "0.75"),
-                ("bottom", "0.75"),
-                ("header", "0.3"),
-                ("footer", "0.3"),
-            ],
-            true,
-        );
+        worksheet.get_page_margins().write_to(&mut writer);
 
         // pageSetup
-        //write_start_tag(&mut writer, "pageSetup", vec![
-        //    ("paperSize", "9"),
-        //    ("orientation", "portrait"),
-        //    ("horizontalDpi", "0"),
-        //    ("verticalDpi", "0"),
-        //    ("r:id", "rId1"),
-        //], true);
+        if worksheet.get_page_setup().has_param() {
+            worksheet.get_page_setup().write_to(&mut writer, &r_id);
+            r_id += 1;
+        }
+
+        // headerFooter
+        worksheet.get_header_footer().write_to(&mut writer);
+
+        // rowBreaks
+        worksheet.get_row_breaks().write_to(&mut writer);
+
+        // colBreaks
+        worksheet.get_column_breaks().write_to(&mut writer);
 
         if worksheet.has_drawing_object() {
             // drawing
